import VueI18Next from '@panter/vue-i18next'
import i18next from 'i18next'
import Fetch from 'i18next-fetch-backend'
import LocalStorageBackend from 'i18next-localstorage-backend'
import Vue from 'vue'
import Vuex, { Store as VuexStore } from 'vuex'
import YAML from 'yaml'

import { PluginStore } from './store'

const ferda_version_el = document.querySelector('#ferda-version')
export const ferda_version = ferda_version_el ? JSON.parse(ferda_version_el.textContent).version : 'no_version'

Vue.use(Vuex)
Vue.use(VueI18Next)

export const store = new VuexStore(PluginStore)

export const get_ferda_pubreq_translations = () => ({
    lng: store.getters['preferences/selected_language'],
    fallbackLng: [store.getters['settings/LANGUAGE_CODE'], 'en'],
    ns: [
        'ferda_pubreq_common',
        'ferda_pubreq_detail',
        'ferda_pubreq_list',
        'ferda_pubreq_rule',
        'common',
        'login',
        'notifications',
        'rule',
        'search',
    ],
    defaultNS: 'ferda_pubreq_common',
    backend: {
        backends: [LocalStorageBackend, Fetch],
        backendOptions: [
            {
                versions: store.getters['settings/LANGUAGES'].reduce((language_versions, lang) => {
                    language_versions[lang[0]] = ferda_version
                    return language_versions
                }, {}),
            },
            {
                loadPath: '/static/ferda_pubreq/locales/{{lng}}/{{ns}}.yml',
                requestOptions: { cache: 'reload' },
                parse: data => YAML.parse(data),
            },
        ],
    },
})

export const i18n = new VueI18Next(i18next)
