"""Ferda public request plugin."""
from typing import Callable, cast

from django.urls import reverse_lazy
from django.utils.translation import gettext_lazy as _
from ferda.models import User
from ferda.plugins import PluginConfig, register

plugin_config = PluginConfig(  # pragma: no cover
    name=_("Public requests"),
    url=reverse_lazy("ferda_pubreq:index"),
    icon="mdi-file-document-outline",
    access=cast(Callable[[User], bool], lambda user: user.has_perm("ferda_pubreq.can_view")),
    permissions=[
        # Required permissions for functions
        #   none: 'get_types'
        #   can_view: view plugin, 'get', 'list'
        #   can_process: 'resolve', 'invalidate'
        ("ferda_pubreq.can_view", "Can get public request information"),
        ("ferda_pubreq.can_process", "Can process public requests"),
    ],
)

register("ferda_pubreq", plugin_config)
